=== modified file 'bzrlib/merge_directive.py'
--- bzrlib/merge_directive.py	2009-05-11 18:53:30 +0000
+++ bzrlib/merge_directive.py	2009-05-11 19:11:14 +0000
@@ -29,6 +29,7 @@
     rio,
     testament,
     timestamp,
+    trace,
     )
 from bzrlib.bundle import (
     serializer as bundle_serializer,
@@ -286,12 +287,17 @@
         else:
             revision = branch.repository.get_revision(self.revision_id)
             subject += revision.get_summary()
-        orig_body = body
-        for hook in self.hooks['merge_request_body']:
-            params = MergeRequestBodyParams(body, orig_body, self,
-                                            to, basename, subject, branch,
-                                            tree)
-            body = hook(params)
+        if getattr(mail_client, 'supports_body', False):
+            orig_body = body
+            for hook in self.hooks['merge_request_body']:
+                params = MergeRequestBodyParams(body, orig_body, self,
+                                                to, basename, subject, branch,
+                                                tree)
+                body = hook(params)
+        elif len(self.hooks['merge_request_body']) > 0:
+            trace.warning('Cannot run merge_request_body hooks because mail'
+                          ' client %s does not support message bodies.',
+                        mail_client.__class__.__name__)
         mail_client.compose_merge_request(to, subject,
                                           ''.join(self.to_lines()),
                                           basename, body)

=== modified file 'bzrlib/tests/test_merge_directive.py'
--- bzrlib/tests/test_merge_directive.py	2009-05-11 18:35:20 +0000
+++ bzrlib/tests/test_merge_directive.py	2009-05-11 19:11:14 +0000
@@ -22,6 +22,7 @@
     mail_client,
     merge_directive,
     tests,
+    trace,
     )
 
 
@@ -726,8 +727,9 @@
 
 class TestBodyHook(tests.TestCaseWithTransport):
 
-    def compose_with_hooks(self, test_hooks):
+    def compose_with_hooks(self, test_hooks, supports_body=True):
         client = HookMailClient({})
+        client.supports_body = supports_body
         for test_hook in test_hooks:
             merge_directive.MergeDirective.hooks.install_named_hook(
                 'merge_request_body', test_hook, 'test')
@@ -742,6 +744,23 @@
             None, tree.branch)
         return client, directive
 
+    def test_no_supports_body(self):
+        test_hook = TestHook('foo')
+        old_warn = trace.warning
+        warnings = []
+        def warn(*args):
+            warnings.append(args)
+        trace.warning = warn
+        try:
+            client, directive = self.compose_with_hooks([test_hook],
+                supports_body=False)
+        finally:
+            trace.warning = old_warn
+        self.assertEqual(0, len(test_hook.calls))
+        self.assertEqual(('Cannot run merge_request_body hooks because mail'
+                          ' client %s does not support message bodies.',
+                          'HookMailClient'), warnings[0])
+
     def test_body_hook(self):
         test_hook = TestHook('foo')
         client, directive = self.compose_with_hooks([test_hook])

